==> mgb-0.6.5.tar.gz: install/convert_ansi.php <==
<?php
	/*
	MGB 0.6.x - OpenSource PHP and MySql Guestbook
	Copyright (C) 2004 - 2011 Juergen Grueneisl - http://www.m-gb.org/

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
	*/

	// ====================== //
	// convert_ansi.php - 1.0 //
	// ====================== //
	//
	// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ //

	// Show all errors but no warnings
	error_reporting(E_ALL & ~E_NOTICE);

	// check if MGB has been already installed
	if (file_exists("../includes/config.inc.php"))
		{
		require ("../includes/config.inc.php");
		if(!isset($mgb_installation_complete))
			{
			echo "It seems as if you haven't installed the MGB yet. You can do that <a href=\"install.php\">here</a>.";
			die();
			}
		}
	else
		{
		echo "The config file could not be found. If you haven't installed the MGB yet, you can do that <a href=\"install.php\">here</a>.";	
		die();
		}

	// load includes
	require ("../includes/config.inc.php");

	if ($_POST['convert'] == 1)
		{
		// Form was sent, deletion confirmed
		echo "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\"\n";
		echo "\t\t\"http://www.w3.org/TR/html4/loose.dtd\">\n";
		echo "<html>\n";
		echo "<head>\n";
		echo "<title>MGB OpenSource Guestbook - convert_utf8.php</title>\n";
		echo "<meta content='text/html; charset=iso-8859-15' http-equiv='content-type'>";
		echo "</head>\n";
		echo "<body>\n";
		echo "<span style=\"font-family: verdana, arial, helvetica, sans-serif; font-size: 12px; font-weight: bold\">Converting all Umlauts to utf-8...<br /><br /></span>\n";

		// connect to database
		$link = @mysql_connect($db['hostname'], $db['username'], $db['password']) or die ("(convert_utf8.php) Error, line 63: ".mysql_error());
		@mysql_select_db($db['dbname'], $link) or die ("(convert_utf8.php) Error, line 64: ".mysql_error());

		// get total number of entries
		$link_count = "SELECT COUNT(ID) FROM ".$db['prefix']."entries";
		$results = @mysql_query($link_count) or die ("(convert_utf8.php) Error, line 68: ".mysql_error());
		$total = @mysql_result($results, 0);

		// load guestbook entries
		$sql = "SELECT ID, name, city, email, icq, aim, msn, hp, message, comment FROM ".$db['prefix']."entries ORDER BY timestamp DESC LIMIT $total";
		$result = @mysql_query($sql, $link) or die ("(convert_utf8.php) Error, line 73: ".mysql_error());

		for($i = 0; $i < @mysql_num_rows($result); $i++)
			{
			$entry[$i] = @mysql_fetch_array($result);
			}

		echo "<span>\n";
		if($total > 0)
			{
			for($i = 0; $i < count($entry); $i++)
				{
				//$entry[$i]['name'] = preg_replace("/&/", "&amp;", $entry[$i]['name']);
				$entry[$i]['name'] = preg_replace("//", "&auml;", $entry[$i]['name']);
				$entry[$i]['name'] = preg_replace("//", "&Auml;", $entry[$i]['name']);
				$entry[$i]['name'] = preg_replace("//", "&ouml;", $entry[$i]['name']);
				$entry[$i]['name'] = preg_replace("//", "&Ouml;", $entry[$i]['name']);
				$entry[$i]['name'] = preg_replace("//", "&uuml;", $entry[$i]['name']);
				$entry[$i]['name'] = preg_replace("//", "&Uuml;", $entry[$i]['name']);
				$entry[$i]['name'] = preg_replace("//", "&szlig;", $entry[$i]['name']);
				$entry[$i]['name'] = preg_replace("//", "&agrave;", $entry[$i]['name']);
				$entry[$i]['name'] = preg_replace("//", "&aacute", $entry[$i]['name']);
				$entry[$i]['name'] = preg_replace("//", "&egrave;", $entry[$i]['name']);
				$entry[$i]['name'] = preg_replace("//", "&eacute;", $entry[$i]['name']);
				$entry[$i]['name'] = preg_replace("//", "&igrave;", $entry[$i]['name']);
				$entry[$i]['name'] = preg_replace("//", "&iacute;", $entry[$i]['name']);
				$entry[$i]['name'] = preg_replace("//", "&ograve;", $entry[$i]['name']);
				$entry[$i]['name'] = preg_replace("//", "&oacute;", $entry[$i]['name']);
				$entry[$i]['name'] = preg_replace("//", "&ugrave;", $entry[$i]['name']);
				$entry[$i]['name'] = preg_replace("//", "&uacute;", $entry[$i]['name']);

				//$entry[$i]['city'] = preg_replace("/&/", "&amp;", $entry[$i]['city']);
				$entry[$i]['city'] = preg_replace("//", "&auml;", $entry[$i]['city']);
				$entry[$i]['city'] = preg_replace("//", "&Auml;", $entry[$i]['city']);
				$entry[$i]['city'] = preg_replace("//", "&ouml;", $entry[$i]['city']);
				$entry[$i]['city'] = preg_replace("//", "&Ouml;", $entry[$i]['city']);
				$entry[$i]['city'] = preg_replace("//", "&uuml;", $entry[$i]['city']);
				$entry[$i]['city'] = preg_replace("//", "&Uuml;", $entry[$i]['city']);
				$entry[$i]['city'] = preg_replace("//", "&szlig;", $entry[$i]['city']);
				$entry[$i]['city'] = preg_replace("//", "&agrave;", $entry[$i]['city']);
				$entry[$i]['city'] = preg_replace("//", "&aacute", $entry[$i]['city']);
				$entry[$i]['city'] = preg_replace("//", "&egrave;", $entry[$i]['city']);
				$entry[$i]['city'] = preg_replace("//", "&eacute;", $entry[$i]['city']);
				$entry[$i]['city'] = preg_replace("//", "&igrave;", $entry[$i]['city']);
				$entry[$i]['city'] = preg_replace("//", "&iacute;", $entry[$i]['city']);
				$entry[$i]['city'] = preg_replace("//", "&ograve;", $entry[$i]['city']);
				$entry[$i]['city'] = preg_replace("//", "&oacute;", $entry[$i]['city']);
				$entry[$i]['city'] = preg_replace("//", "&ugrave;", $entry[$i]['city']);
				$entry[$i]['city'] = preg_replace("//", "&uacute;", $entry[$i]['city']);

				//$entry[$i]['message'] = preg_replace("/&/", "&amp;", $entry[$i]['message']);
				$entry[$i]['message'] = preg_replace("//", "&auml;", $entry[$i]['message']);
				$entry[$i]['message'] = preg_replace("//", "&Auml;", $entry[$i]['message']);
				$entry[$i]['message'] = preg_replace("//", "&ouml;", $entry[$i]['message']);
				$entry[$i]['message'] = preg_replace("//", "&Ouml;", $entry[$i]['message']);
				$entry[$i]['message'] = preg_replace("//", "&uuml;", $entry[$i]['message']);
				$entry[$i]['message'] = preg_replace("//", "&Uuml;", $entry[$i]['message']);
				$entry[$i]['message'] = preg_replace("//", "&szlig;", $entry[$i]['message']);
				$entry[$i]['message'] = preg_replace("//", "&agrave;", $entry[$i]['message']);
				$entry[$i]['message'] = preg_replace("//", "&aacute", $entry[$i]['message']);
				$entry[$i]['message'] = preg_replace("//", "&egrave;", $entry[$i]['message']);
				$entry[$i]['message'] = preg_replace("//", "&eacute;", $entry[$i]['message']);
				$entry[$i]['message'] = preg_replace("//", "&igrave;", $entry[$i]['message']);
				$entry[$i]['message'] = preg_replace("//", "&iacute;", $entry[$i]['message']);
				$entry[$i]['message'] = preg_replace("//", "&ograve;", $entry[$i]['message']);
				$entry[$i]['message'] = preg_replace("//", "&oacute;", $entry[$i]['message']);
				$entry[$i]['message'] = preg_replace("//", "&ugrave;", $entry[$i]['message']);
				$entry[$i]['message'] = preg_replace("//", "&uacute;", $entry[$i]['message']);

				//$entry[$i]['comment'] = preg_replace("/&/", "&amp;", $entry[$i]['comment']);
				$entry[$i]['comment'] = preg_replace("//", "&auml;", $entry[$i]['comment']);
				$entry[$i]['comment'] = preg_replace("//", "&Auml;", $entry[$i]['comment']);
				$entry[$i]['comment'] = preg_replace("//", "&ouml;", $entry[$i]['comment']);
				$entry[$i]['comment'] = preg_replace("//", "&Ouml;", $entry[$i]['comment']);
				$entry[$i]['comment'] = preg_replace("//", "&uuml;", $entry[$i]['comment']);
				$entry[$i]['comment'] = preg_replace("//", "&Uuml;", $entry[$i]['comment']);
				$entry[$i]['comment'] = preg_replace("//", "&szlig;", $entry[$i]['comment']);
				$entry[$i]['comment'] = preg_replace("//", "&agrave;", $entry[$i]['comment']);
				$entry[$i]['comment'] = preg_replace("//", "&aacute", $entry[$i]['comment']);
				$entry[$i]['comment'] = preg_replace("//", "&egrave;", $entry[$i]['comment']);
				$entry[$i]['comment'] = preg_replace("//", "&eacute;", $entry[$i]['comment']);
				$entry[$i]['comment'] = preg_replace("//", "&igrave;", $entry[$i]['comment']);
				$entry[$i]['comment'] = preg_replace("//", "&iacute;", $entry[$i]['comment']);
				$entry[$i]['comment'] = preg_replace("//", "&ograve;", $entry[$i]['comment']);
				$entry[$i]['comment'] = preg_replace("//", "&oacute;", $entry[$i]['comment']);
				$entry[$i]['comment'] = preg_replace("//", "&ugrave;", $entry[$i]['comment']);
				$entry[$i]['comment'] = preg_replace("//", "&uacute;", $entry[$i]['comment']);

				// save data to database
				$sql = "UPDATE ".$db['prefix']."entries SET
								`name` = '".$entry[$i]['name']."',
								`city` = '".$entry[$i]['city']."',
								`message` = '".$entry[$i]['message']."',
								`comment` = '".$entry[$i]['comment']."'
								WHERE ID=".$entry[$i]['ID']." LIMIT 1";

				if ( @mysql_query($sql, $link) or die ("(convert_utf8.php) Error, line 129: ".mysql_error()) )
					{
					echo "Entry ".$i.": OK!<br />\n";
					}
				}
			}
		echo "</span>\n";
		}
	else
		{
		if (date('H') < "12")
			{
			$greeting = "Good Morning";
			}
		if (date('H') > "12")
			{
			$greeting = "Hello";
			}
		if (date('H') > "18")
			{
			$greeting ="Good Evening";
			}

		echo "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\"\n";
		echo "\t\t\"http://www.w3.org/TR/html4/loose.dtd\">\n";
		echo "<html>\n";
		echo "<head>\n";
		echo "<title>MGB OpenSource Guestbook - delete_sql.php</title>\n";
		echo "<meta content='text/html; charset=iso-8859-15' http-equiv='content-type'>";
		echo "</head>\n";
		echo "<body>\n";
		echo "<form action=\"convert_ansi.php\" method=\"post\">\n";
		echo "<input type=\"hidden\" name=\"convert\" value=\"1\">\n";
		echo "<span style=\"font-family: verdana, arial, helvetica, sans-serif; font-size: 12px; font-weight: bold\">".$greeting.", Dave.<br /><br />Are you really sure you want to convert all entries to ansi-code?";
		echo "<br /><br />\n";
		echo "<input type=\"submit\" class=\"button\" name=\"confirm\" value=\"Yes, HAL. I'm sure.\">\n";
		echo "</form>\n";
		echo "</body>\n";
		echo "</html>\n";
		}
?>

==> mgb-0.6.8.tar.gz: install/convert_ansi.php <==
<?php
	/*
	MGB 0.6.x - OpenSource PHP and MySql Guestbook
	Copyright (C) 2004 - 2011 Juergen Grueneisl - http://www.m-gb.org/

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
	*/

	// ====================== //
	// convert_ansi.php - 1.1 //
	// ====================== //
	//
	// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ //

	// Show all errors but no warnings
	error_reporting(E_ALL & ~E_NOTICE);

	// check if MGB has been already installed
	if (file_exists("../includes/config.inc.php"))
		{
		require ("../includes/config.inc.php");
		if(!isset($mgb_installation_complete))
			{
			echo "It seems as if you haven't installed the MGB yet. You can do that <a href=\"install.php\">here</a>.";
			die();
			}
		}
	else
		{
		echo "The config file could not be found. If you haven't installed the MGB yet, you can do that <a href=\"install.php\">here</a>.";	
		die();
		}

	// load includes
	require ("../includes/config.inc.php");

	if ($_POST['convert'] == 1)
		{
		// Form was sent, deletion confirmed
		echo "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\"\n";
		echo "\t\t\"http://www.w3.org/TR/html4/loose.dtd\">\n";
		echo "<html>\n";
		echo "<head>\n";
		echo "<title>MGB OpenSource Guestbook - convert_utf8.php</title>\n";
		echo "<meta content='text/html; charset=iso-8859-15' http-equiv='content-type'>";
		echo "</head>\n";
		echo "<body>\n";
		echo "<span style=\"font-family: verdana, arial, helvetica, sans-serif; font-size: 12px; font-weight: bold\">Converting all Umlauts to utf-8...<br /><br /></span>\n";

		// connect to database
		$link = @mysql_connect($db['hostname'], $db['username'], $db['password']) or die ("(convert_ansi.php) Error, line 63: ".mysql_error());
		@mysql_select_db($db['dbname'], $link) or die ("(convert_utf8.php) Error, line 64: ".mysql_error());

		// get total number of entries
		$link_count = "SELECT COUNT(ID) FROM ".$db['prefix']."entries";
		$results = @mysql_query($link_count) or die ("(convert_ansi.php) Error, line 68: ".mysql_error());
		$total = @mysql_result($results, 0);

		// load guestbook entries
		$sql = "SELECT ID, name, city, email, icq, aim, msn, hp, message, comment FROM ".$db['prefix']."entries ORDER BY timestamp DESC LIMIT $total";
		$result = @mysql_query($sql, $link) or die ("(convert_ansi.php) Error, line 73: ".mysql_error());

		for($i = 0; $i < @mysql_num_rows($result); $i++)
			{
			$entry[$i] = @mysql_fetch_array($result);
			}

		echo "<span>\n";
		if($total > 0)
			{
			for($i = 0; $i < count($entry); $i++)
				{
				//$entry[$i]['name'] = preg_replace("/&/", "&amp;", $entry[$i]['name']);
				$entry[$i]['name'] = preg_replace("//", "&auml;", $entry[$i]['name']);
				$entry[$i]['name'] = preg_replace("//", "&Auml;", $entry[$i]['name']);
				$entry[$i]['name'] = preg_replace("//", "&ouml;", $entry[$i]['name']);
				$entry[$i]['name'] = preg_replace("//", "&Ouml;", $entry[$i]['name']);
				$entry[$i]['name'] = preg_replace("//", "&uuml;", $entry[$i]['name']);
				$entry[$i]['name'] = preg_replace("//", "&Uuml;", $entry[$i]['name']);
				$entry[$i]['name'] = preg_replace("//", "&szlig;", $entry[$i]['name']);
				$entry[$i]['name'] = preg_replace("//", "&agrave;", $entry[$i]['name']);
				$entry[$i]['name'] = preg_replace("//", "&aacute", $entry[$i]['name']);
				$entry[$i]['name'] = preg_replace("//", "&egrave;", $entry[$i]['name']);
				$entry[$i]['name'] = preg_replace("//", "&eacute;", $entry[$i]['name']);
				$entry[$i]['name'] = preg_replace("//", "&igrave;", $entry[$i]['name']);
				$entry[$i]['name'] = preg_replace("//", "&iacute;", $entry[$i]['name']);
				$entry[$i]['name'] = preg_replace("//", "&ograve;", $entry[$i]['name']);
				$entry[$i]['name'] = preg_replace("//", "&oacute;", $entry[$i]['name']);
				$entry[$i]['name'] = preg_replace("//", "&ugrave;", $entry[$i]['name']);
				$entry[$i]['name'] = preg_replace("//", "&uacute;", $entry[$i]['name']);

				//$entry[$i]['city'] = preg_replace("/&/", "&amp;", $entry[$i]['city']);
				$entry[$i]['city'] = preg_replace("//", "&auml;", $entry[$i]['city']);
				$entry[$i]['city'] = preg_replace("//", "&Auml;", $entry[$i]['city']);
				$entry[$i]['city'] = preg_replace("//", "&ouml;", $entry[$i]['city']);
				$entry[$i]['city'] = preg_replace("//", "&Ouml;", $entry[$i]['city']);
				$entry[$i]['city'] = preg_replace("//", "&uuml;", $entry[$i]['city']);
				$entry[$i]['city'] = preg_replace("//", "&Uuml;", $entry[$i]['city']);
				$entry[$i]['city'] = preg_replace("//", "&szlig;", $entry[$i]['city']);
				$entry[$i]['city'] = preg_replace("//", "&agrave;", $entry[$i]['city']);
				$entry[$i]['city'] = preg_replace("//", "&aacute", $entry[$i]['city']);
				$entry[$i]['city'] = preg_replace("//", "&egrave;", $entry[$i]['city']);
				$entry[$i]['city'] = preg_replace("//", "&eacute;", $entry[$i]['city']);
				$entry[$i]['city'] = preg_replace("//", "&igrave;", $entry[$i]['city']);
				$entry[$i]['city'] = preg_replace("//", "&iacute;", $entry[$i]['city']);
				$entry[$i]['city'] = preg_replace("//", "&ograve;", $entry[$i]['city']);
				$entry[$i]['city'] = preg_replace("//", "&oacute;", $entry[$i]['city']);
				$entry[$i]['city'] = preg_replace("//", "&ugrave;", $entry[$i]['city']);
				$entry[$i]['city'] = preg_replace("//", "&uacute;", $entry[$i]['city']);

				//$entry[$i]['message'] = preg_replace("/&/", "&amp;", $entry[$i]['message']);
				$entry[$i]['message'] = preg_replace("//", "&auml;", $entry[$i]['message']);
				$entry[$i]['message'] = preg_replace("//", "&Auml;", $entry[$i]['message']);
				$entry[$i]['message'] = preg_replace("//", "&ouml;", $entry[$i]['message']);
				$entry[$i]['message'] = preg_replace("//", "&Ouml;", $entry[$i]['message']);
				$entry[$i]['message'] = preg_replace("//", "&uuml;", $entry[$i]['message']);
				$entry[$i]['message'] = preg_replace("//", "&Uuml;", $entry[$i]['message']);
				$entry[$i]['message'] = preg_replace("//", "&szlig;", $entry[$i]['message']);
				$entry[$i]['message'] = preg_replace("//", "&agrave;", $entry[$i]['message']);
				$entry[$i]['message'] = preg_replace("//", "&aacute", $entry[$i]['message']);
				$entry[$i]['message'] = preg_replace("//", "&egrave;", $entry[$i]['message']);
				$entry[$i]['message'] = preg_replace("//", "&eacute;", $entry[$i]['message']);
				$entry[$i]['message'] = preg_replace("//", "&igrave;", $entry[$i]['message']);
				$entry[$i]['message'] = preg_replace("//", "&iacute;", $entry[$i]['message']);
				$entry[$i]['message'] = preg_replace("//", "&ograve;", $entry[$i]['message']);
				$entry[$i]['message'] = preg_replace("//", "&oacute;", $entry[$i]['message']);
				$entry[$i]['message'] = preg_replace("//", "&ugrave;", $entry[$i]['message']);
				$entry[$i]['message'] = preg_replace("//", "&uacute;", $entry[$i]['message']);

				//$entry[$i]['comment'] = preg_replace("/&/", "&amp;", $entry[$i]['comment']);
				$entry[$i]['comment'] = preg_replace("//", "&auml;", $entry[$i]['comment']);
				$entry[$i]['comment'] = preg_replace("//", "&Auml;", $entry[$i]['comment']);
				$entry[$i]['comment'] = preg_replace("//", "&ouml;", $entry[$i]['comment']);
				$entry[$i]['comment'] = preg_replace("//", "&Ouml;", $entry[$i]['comment']);
				$entry[$i]['comment'] = preg_replace("//", "&uuml;", $entry[$i]['comment']);
				$entry[$i]['comment'] = preg_replace("//", "&Uuml;", $entry[$i]['comment']);
				$entry[$i]['comment'] = preg_replace("//", "&szlig;", $entry[$i]['comment']);
				$entry[$i]['comment'] = preg_replace("//", "&agrave;", $entry[$i]['comment']);
				$entry[$i]['comment'] = preg_replace("//", "&aacute", $entry[$i]['comment']);
				$entry[$i]['comment'] = preg_replace("//", "&egrave;", $entry[$i]['comment']);
				$entry[$i]['comment'] = preg_replace("//", "&eacute;", $entry[$i]['comment']);
				$entry[$i]['comment'] = preg_replace("//", "&igrave;", $entry[$i]['comment']);
				$entry[$i]['comment'] = preg_replace("//", "&iacute;", $entry[$i]['comment']);
				$entry[$i]['comment'] = preg_replace("//", "&ograve;", $entry[$i]['comment']);
				$entry[$i]['comment'] = preg_replace("//", "&oacute;", $entry[$i]['comment']);
				$entry[$i]['comment'] = preg_replace("//", "&ugrave;", $entry[$i]['comment']);
				$entry[$i]['comment'] = preg_replace("//", "&uacute;", $entry[$i]['comment']);

				// save data to database
				$sql = "UPDATE ".$db['prefix']."entries SET
								`name` = '".$entry[$i]['name']."',
								`city` = '".$entry[$i]['city']."',
								`message` = '".$entry[$i]['message']."',
								`comment` = '".$entry[$i]['comment']."'
								WHERE ID=".$entry[$i]['ID']." LIMIT 1";

				if ( @mysql_query($sql, $link) or die ("(convert_ansi.php) Error, line 169: ".mysql_error()) )
					{
					echo "<span style=\"font-family: verdana, arial, helvetica, sans-serif; font-size: 12px; font-weight: bold\">Entry ".$i.": OK!</span><br>\n";
					}
				}
			}
		echo "</span>\n";
		}
	else
		{
		if (date('H') < "12")
			{
			$greeting = "Good Morning";
			}
		if (date('H') > "12")
			{
			$greeting = "Hello";
			}
		if (date('H') > "18")
			{
			$greeting ="Good Evening";
			}

		echo "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\"\n";
		echo "\t\t\"http://www.w3.org/TR/html4/loose.dtd\">\n";
		echo "<html>\n";
		echo "<head>\n";
		echo "<title>MGB OpenSource Guestbook - delete_sql.php</title>\n";
		echo "<meta content='text/html; charset=iso-8859-15' http-equiv='content-type'>";
		echo "</head>\n";
		echo "<body>\n";
		echo "<form action=\"convert_ansi.php\" method=\"post\">\n";
		echo "<input type=\"hidden\" name=\"convert\" value=\"1\">\n";
		echo "<span style=\"font-family: verdana, arial, helvetica, sans-serif; font-size: 12px; font-weight: bold\">".$greeting.", Dave.<br /><br />Are you really sure you want to convert all entries to ansi-code?";
		echo "<br /><br />\n";
		echo "<input type=\"submit\" class=\"button\" name=\"confirm\" value=\"Yes, HAL. I'm sure.\">\n";
		echo "</form>\n";
		echo "</body>\n";
		echo "</html>\n";
		}
?>
